@@ -1,6 +1,6 @@
 """Methods to build in the world."""
 
-from mcwb.api import make_tunnel
+from mcwb.api import get_block, make_tunnel, polygon
 from mcwb.types import (
     Anchor,
     Anchor3,
@@ -13,9 +13,8 @@ from mcwb.types import (
     Row,
     Vec3,
 )
-from mcwb.volume import Volume
 from mcwb.blocks import Blocks
-
+from mcwb.volume import Volume
 
 __all__ = [
     "Anchor",
@@ -31,4 +30,6 @@ __all__ = [
     "Vec3",
     "Volume",
     "make_tunnel",
+    "polygon",
+    "get_block",
 ]
