@@ -94,11 +94,11 @@ def validate(items: Items):
     # np ragged array is deprecated but only supplys a warning currently
     with np.warnings.catch_warnings(record=True) as warning:
         np.warnings.simplefilter("always")
-        narray = np.array(items)
+        n_array = np.array(items)
         if warning and "ragged nested" in str(warning[-1].message):
             ragged = True
 
-    return int(narray.ndim) if narray.dtype == Item and not ragged else 0
+    return int(n_array.ndim) if not ragged else 0
 
 
 def shift(arr: np.ndarray, vec: Vec3, fill: Item = Item.AIR) -> np.ndarray:
